pub struct Args {
pub bases: Vec<String>,
pub protected: Vec<String>,
pub no_update: bool,
pub update: bool,
pub update_interval: Option<u64>,
pub no_confirm: bool,
pub confirm: bool,
pub no_detach: bool,
pub detach: bool,
pub delete: Vec<DeleteRange>,
pub dry_run: bool,
}Fields
bases: Vec<String>Comma separated multiple names of branches.
All the other branches are compared with the upstream branches of those branches.
[default: branches that tracks git symbolic-ref refs/remotes/*/HEAD] [config: trim.bases]
The default value is a branch that tracks git symbolic-ref refs/remotes/*/HEAD.
They might not be reflected correctly when the HEAD branch of your remote repository is changed.
You can see the changed HEAD branch name with git remote show <remote>
and apply it to your local repository with git remote set-head <remote> --auto.
protected: Vec<String>Comma separated multiple glob patterns (e.g. release-*, feature/*) of branches that should never be deleted.
[config: trim.protected]
no_update: boolDo not update remotes [config: trim.update]
update: boolupdate_interval: Option<u64>Prevents too frequent updates. Seconds between updates in seconds. 0 to disable. [default: 5] [config: trim.updateInterval]
no_confirm: boolDo not ask confirm [config: trim.confirm]
confirm: boolno_detach: boolDo not detach when HEAD is about to be deleted [config: trim.detach]
detach: booldelete: Vec<DeleteRange>Comma separated values of <delete range>[:<remote name>].
Delete range is one of the merged, merged-local, merged-remote, stray, diverged, local, remote.
:<remote name> is only necessary to a <delete range> when the range is applied to remote branches.
You can use * as <remote name> to delete a range of branches from all remotes.
[default : merged:origin] [config: trim.delete]
merged implies merged-local,merged-remote.
merged-local will delete merged tracking local branches.
merged-remote:<remote> will delete merged upstream branches from <remote>.
stray will delete tracking local branches, which is not merged, but the upstream is gone.
diverged:<remote> will delete merged tracking local branches, and their upstreams from <remote> even if the upstreams are not merged and diverged from local ones.
local will delete non-tracking merged local branches.
remote:<remote> will delete non-upstream merged remote tracking branches.
Use with caution when you are using other than merged. It might lose changes, and even nuke repositories.
dry_run: boolDo not delete branches, show what branches will be deleted.
Implementations